@@ -31,6 +31,7 @@ from zope.publisher.interfaces import NotFound
 from zope.traversing.interfaces import ITraversable
 from zope.traversing.interfaces import TraversalError
 
+import functools
 import logging
 import six
 
@@ -217,6 +218,11 @@ class DefaultImageScalingFactory(object):
         if height is None and width is None:
             dummy, format_ = orig_value.contentType.split("/", 1)
             return None, format_, (orig_value._width, orig_value._height)
+        elif not parameters and height and width \
+                and height == getattr(orig_value, "_height", None) \
+                and width == getattr(orig_value, "_width", None):
+            dummy, format_ = orig_value.contentType.split("/", 1)
+            return orig_value, format_, (orig_value._width, orig_value._height)
         orig_data = None
         try:
             orig_data = orig_value.open()
@@ -390,12 +396,17 @@ class ImageScaling(BrowserView):
     def getHighPixelDensityScales(self):
         return getHighPixelDensityScales()
 
-    def modified(self):
+    def modified(self, fieldname=None):
         """Provide a callable to return the modification time of content
         items, so stored image scales can be invalidated.
         """
         context = aq_base(self.context)
-        date = DateTime(context._p_mtime)
+        if fieldname is not None:
+            field = getattr(context, fieldname, None)
+            field_p_mtime = getattr(field, "_p_mtime", None)
+            date = DateTime(field_p_mtime or context._p_mtime)
+        else:
+            date = DateTime(context._p_mtime)
         return date.millis()
 
     def scale(
@@ -425,7 +436,10 @@ class ImageScaling(BrowserView):
             width, height = available[scale]
         if IDisableCSRFProtection and self.request is not None:
             alsoProvides(self.request, IDisableCSRFProtection)
-        storage = AnnotationStorage(self.context, self.modified)
+        storage = AnnotationStorage(
+            self.context,
+            functools.partial(self.modified, fieldname)
+        )
         info = storage.scale(
             fieldname=fieldname,
             height=height,
